# page_screenshot

## Introduction
网页截图，启动有界面的浏览器，滚动截图，最后拼接成完整的网页长截图

## Example
from page_screenshot.run_factory import run

run('https://baidu.com')


## Communication
- 未来已来 203737026

## Copyright and License
code for everything